@@ -49,9 +49,6 @@ class InternalBackendConf(SharedBackendConfUtils):
     def spreadRddRetriesTimeout(self):
         return self._jconf.spreadRddRetriesTimeout()
 
-    def nodeIcedDir(self):
-        return self._get_option(self._jconf.nodeIcedDir())
-
 
     #
     # Setters
@@ -84,7 +81,3 @@ class InternalBackendConf(SharedBackendConfUtils):
     def setSpreadRddRetriesTimeout(self, value):
         self._jconf.setSpreadRddRetriesTimeout(value)
         return self
-
-    def setNodeIcedDir(self, value):
-        self._jconf.setNodeIcedDir(value)
-        return self
