@@ -29,6 +29,7 @@ class H2ODRFClassifier(H2ODRF):
                  calibrationDataFrame=None,
                  ignoredCols=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
@@ -91,6 +92,7 @@ class H2ODRFClassifier(H2ODRF):
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.classification.H2ODRFClassifier", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
+        kwargs = self._updateInitKwargs(kwargs)
 
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
