@@ -79,7 +79,6 @@ class H2ODeepLearningRegressor(H2ODeepLearning):
                  quietMode=False,
                  scoreValidationSampling="Uniform",
                  overwriteWithBestModel=True,
-                 autoencoder=False,
                  useAllFactorLevels=True,
                  standardize=True,
                  diagnostics=True,
@@ -135,6 +134,9 @@ class H2ODeepLearningRegressor(H2ODeepLearning):
                 kwargs['calculateFeatureImportances'] = kwargs['variableImportances']
             del kwargs['variableImportances']
             warn("The parameter 'variableImportances' is deprecated and will be removed in the version 3.36.")
+        if 'autoencoder' in kwargs:
+            del kwargs['autoencoder']
+            warn("The parameter 'autoencoder' is deprecated and will be removed in the version 3.36.")
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
         self._set(**kwargs)
