@@ -32,6 +32,7 @@ class H2OGLMRegressor(H2OGLM):
                  betaConstraints=None,
                  interactionPairs=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
@@ -82,6 +83,7 @@ class H2OGLMRegressor(H2OGLM):
                  maxConfusionMatrixSize=20,
                  computePValues=False,
                  removeCollinearCols=False,
+                 generateScoringHistory=False,
                  modelId=None,
                  nfolds=0,
                  keepCrossValidationModels=True,
@@ -94,21 +96,21 @@ class H2OGLMRegressor(H2OGLM):
                  foldAssignment="AUTO",
                  ignoreConstCols=True,
                  scoreEachIteration=False,
+                 checkpoint=None,
                  stoppingRounds=0,
                  maxRuntimeSecs=0.0,
                  stoppingMetric="AUTO",
                  stoppingTolerance=0.001,
                  customMetricFunc=None,
                  exportCheckpointsDir=None,
-                 **kwargs):
+                 aucType="AUTO"):
         Initializer.load_sparkling_jar()
         super(H2OGLM, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.regression.H2OGLMRegressor", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
-        if 'distribution' in kwargs:
-            del kwargs['distribution']
-            warn("The parameter 'distribution' is deprecated and will be removed in the version 3.34.")
+        kwargs = self._updateInitKwargs(kwargs)
+
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
         self._set(**kwargs)
