@@ -4,7 +4,6 @@ from __future__ import division, print_function, absolute_import, unicode_litera
 from h2o.utils.compatibility import *  # NOQA
 
 import json
-import re
 import sys
 import time
 
@@ -262,8 +261,19 @@ class H2OCluster(H2OSchema):
     def _translate_job_type(self, type):
         if type is None:
             return ('Removed')
-        m = re.match(r"^Key<(\w+)>", type)
-        return m.group(1) if m else "Unknown"
+        type_mapping = dict([
+            ('Key<Frame>', 'Frame'),
+            ('Key<Model>', 'Model'),
+            ('Key<Grid>', 'Grid'),
+            ('Key<PartialDependence>', 'PartialDependence'),
+            ('Key<AutoML>', 'Auto Model'),
+            ('Key<ScalaCodeResult>', 'Scala Code Execution'),
+            ('Key<KeyedVoid>', 'Void')
+        ])
+        if type in type_mapping:
+            return type_mapping[type]
+        else:
+            return 'Unknown'
 
     def _get_cluster_status_info_values(self):
         if self._retrieved_at + self.REFRESH_INTERVAL < time.time():
@@ -279,6 +289,7 @@ class H2OCluster(H2OSchema):
             status += ", healthy"
         else:
             status += ", %d nodes are not healthy" % unhealthy_nodes
+        api_extensions = self.list_api_extensions()
         values = [get_human_readable_time(self.cloud_uptime_millis),
                   self.cloud_internal_timezone,
                   self.datafile_parser_timezone,
@@ -293,6 +304,7 @@ class H2OCluster(H2OSchema):
                   h2o.connection().base_url,
                   json.dumps(h2o.connection().proxy),
                   self.internal_security_enabled,
+                  ', '.join(api_extensions),
                   "%d.%d.%d %s" % tuple(sys.version_info[:4])]
         return values
 
@@ -300,7 +312,7 @@ class H2OCluster(H2OSchema):
 _cluster_status_info_keys = ["H2O_cluster_uptime", "H2O_cluster_timezone", "H2O_data_parsing_timezone",
             "H2O_cluster_version", "H2O_cluster_version_age", "H2O_cluster_name", "H2O_cluster_total_nodes",
             "H2O_cluster_free_memory", "H2O_cluster_total_cores", "H2O_cluster_allowed_cores", "H2O_cluster_status",
-            "H2O_connection_url", "H2O_connection_proxy", "H2O_internal_security", "Python_version"]
+            "H2O_connection_url", "H2O_connection_proxy", "H2O_internal_security", "H2O_API_Extensions", "Python_version"]
     
 _cluster_status_detailed_info_keys = ["h2o", "healthy", "last_ping", "num_cpus", "sys_load", "mem_value_size",
                                       "free_mem", "pojo_mem", "swap_mem", "free_disk", "max_disk", "pid", "num_keys",
