@@ -1,23 +1,22 @@
-from h2o.plot import decorate_plot_result, get_matplotlib_pyplot, RAISE_ON_FIGURE_ACCESS
+from h2o.utils.ext_dependencies import get_matplotlib_pyplot
 from h2o.utils.typechecks import assert_is_type, I
 
 
 class StandardCoef:
 
-    def _std_coef_plot(self, num_of_features=None, server=False, save_plot_path=None):
+    def _std_coef_plot(self, num_of_features=None, server=False):
         """
         Plot a GLM model"s standardized coefficient magnitudes.
 
         :param num_of_features: the number of features shown in the plot.
         :param server: if true set server settings to matplotlib and show the graph
-        :param save_plot_path: a path to save the plot via using matplotlib function savefig
 
-        :returns: object that contains the resulting figure (can be accessed using result.figure())
+        :returns: None.
         """
         assert_is_type(num_of_features, None, I(int, lambda x: x > 0))
 
         plt = get_matplotlib_pyplot(server)
-        if not plt: return decorate_plot_result(figure=RAISE_ON_FIGURE_ACCESS)
+        if not plt: return
 
         # get unsorted tuple of labels and coefficients
         unsorted_norm_coef = self.coef_norm().items()
@@ -81,21 +80,25 @@ class StandardCoef:
         # if positive create positive legend
         if "#1F77B4" in signage[0:num_of_features] and "#FF7F0E" not in signage[0:num_of_features]:
             color_ids = ("Positive",)
-            markers = [plt.Line2D([0, 0], [0, 0], color=color, marker="s", linestyle="", markersize=10)
-                       for color in set(signage[0:num_of_features])]
-            plt.legend(markers, color_ids, numpoints=1, loc="best", frameon=False, fontsize=13)
+            markers = [plt.Line2D([0, 0], [0, 0], color=color, marker="s", linestyle="")
+                       for color in signage[0:num_of_features]]
+            lgnd = plt.legend(markers, color_ids, numpoints=1, loc="best", frameon=False, fontsize=13)
+            lgnd.legendHandles[0]._legmarker.set_markersize(10)
         # if neg create neg legend
         elif "#FF7F0E" in signage[0:num_of_features] and "#1F77B4" not in signage[0:num_of_features]:
             color_ids = ("Negative",)
-            markers = [plt.Line2D([0, 0], [0, 0], color=color, marker="s", linestyle="", markersize=10)
+            markers = [plt.Line2D([0, 0], [0, 0], color=color, marker="s", linestyle="")
                        for color in set(signage[0:num_of_features])]
-            plt.legend(markers, color_ids, numpoints=1, loc="best", frameon=False, fontsize=13)
+            lgnd = plt.legend(markers, color_ids, numpoints=1, loc="best", frameon=False, fontsize=13)
+            lgnd.legendHandles[0]._legmarker.set_markersize(10)
         # if both provide both colors in legend
         else:
             color_ids = ("Positive", "Negative")
-            markers = [plt.Line2D([0, 0], [0, 0], color=color, marker="s", linestyle="", markersize=10)
+            markers = [plt.Line2D([0, 0], [0, 0], color=color, marker="s", linestyle="")
                        for color in ['#1F77B4', '#FF7F0E']] # blue should always be positive, orange negative
-            plt.legend(markers, color_ids, numpoints=1, loc="best", frameon=False, fontsize=13)
+            lgnd = plt.legend(markers, color_ids, numpoints=1, loc="best", frameon=False, fontsize=13)
+            lgnd.legendHandles[0]._legmarker.set_markersize(10)
+            lgnd.legendHandles[1]._legmarker.set_markersize(10)
 
         # Hide the right and top spines, color others grey
         ax.spines["right"].set_visible(False)
@@ -107,9 +110,6 @@ class StandardCoef:
         plt.yticks(pos[0:num_of_features], feature_labels[0:num_of_features])
         plt.tick_params(axis="x", which="minor", bottom="off", top="off",  labelbottom="off")
         plt.title("Standardized Coef. Magnitudes: H2O GLM", fontsize=20)
-        if save_plot_path is not None:
-            plt.savefig(fname=save_plot_path)
         # show plot
         if server:
             plt.show()
-        return decorate_plot_result(figure=fig) 
